@@ -5,7 +5,7 @@
 import re
 from PyQt4 import QtCore,QtGui
 from PyQt4.QtCore import Qt
-from plugins_api import init_plugin_system, filter_plugins_by_capability
+from plugins.plugins_api import init_plugin_system, filter_plugins_by_capability
 from recent_files import RecentFiles
 
 
@@ -309,7 +309,7 @@ class KhtTextEdit(QtGui.QTextEdit):
     
         # Replace
         # self is the QTextEdit
-        if args[3]:
+        if args[3]==True:
             cursor = self.document().find(QtCore.QRegExp(what),
                                     self.textCursor(), flags)                
         else:
@@ -328,23 +328,25 @@ class KhtTextEdit(QtGui.QTextEdit):
         arg[2] -> QtGui.QTextDocument.FindBackward
         arg[3] -> QtGui.QTextDocument.RegEx
         """
+        print 'find called'
+        
         # Use flags for case match
         flags = QtGui.QTextDocument.FindFlags()
         if args[0]==True:
-            flags = flags|QtGui.QTextDocument.FindCaseSensitively
+            flags = flags | QtGui.QTextDocument.FindCaseSensitively
         if args[1]==True:
-            flags = flags|QtGui.QTextDocument.FindWholeWords
+            flags = flags | QtGui.QTextDocument.FindWholeWords
         if args[2]==True:
-            flags = flags|QtGui.QTextDocument.FindBackward
+            flags = flags | QtGui.QTextDocument.FindBackward
 
-        if args[3]:
+        if args[3]==True:
             cursor = self.document().find(QtCore.QRegExp(what),
                                         self.textCursor(), flags)
         else:
             cursor = self.document().find(what, self.textCursor(), flags)
 
         if not cursor.isNull():
-            self.setTextCursor(cursor)
+            self.setTextCursor(cursor)            
             
     def duplicate(self):
         """Duplicate the current line or selection"""
